from mindt_Selino.dtMinimisation import *
from mindt_Selino.optimizedQuineMcCluskey import OptimizedQuineMcCluskey

class DtMinOptimized(DtMinimisation):
    def __init__(self, path):
        readInput = ReadInput()

        input = readInput.readIntervalInput(path)

        newImplicants = set()

        for element in input:
            newImplicants.update(element.unfold(readInput.stages))

        staggeredImplicants = list(newImplicants)

        output = OptimizedQuineMcCluskey.execute(staggeredImplicants, readInput.stages)

        self.input = input
        self.staggeredImplicants = staggeredImplicants
        self.output = list(output)


from mindt_Selino.Resources.readInput import *
from mindt_Selino.Resources.intervalsGenerator import *
from mindt_Selino.quineMcCluskey import *
import sys

implicant = IntervalImplicant([(0,3), (2,4), (5,6)])
implicant2 = IntervalImplicant([(0,3), (2,4), (5,6)])

implicant3 = implicant.matches(implicant2)

print(implicant, implicant2, implicant3)


from mindt_Selino.dtMinOptimized import DtMinOptimized

minimization = DtMinOptimized("tests/test2/GeneratedExamples/ex.5_3_10")

minimization.printInput()

minimization.printStaggeredInput()

minimization.printOutput()

minimization.saveOutputInFile("output.txt")


import pandas as pd
import seaborn as sns

df = pd.read_csv('tiempos.csv')
filtered = df.groupby(["programa", "ejemplo"])["tiempo"].mean()

prueba = filtered.reset_index()

print(prueba)

prueba['tiempo'] = prueba['tiempo'].round(4)

prueba.to_csv('filtrado.txt', index=False)


from mindt_Selino.Implicant.booleanImplicant import *
from mindt_Selino.Implicant.intervalmplicant import *
from mindt_Selino.Implicant.optimizedintervalImplicant import *

class ReadInput():
    @classmethod
    def readBooleanInput(self, filename):
        file = open(filename)
        lines = file.read().splitlines()
        input = []

        for line in lines:
            implicant = BooleanImplicant(line)
            input.append(implicant)

        return input
    
    @classmethod
    def readIntervalInput(self, filename):
        file = open(filename)
        lines = file.read().splitlines()
        input = []
        
        numVariables = int(lines[0])
        lines.pop(0)

        setsList = []

        for i in range(numVariables):
            nuevoSetVariable = set()
            nuevoSetVariable.update([0, int(lines[0])])
            lines.pop(0)
            setsList.append(nuevoSetVariable)

        for element in lines:
            x = element.split()
            tuples = [] 
            nueva_lista = [x[i:i+2] for i in range(0, len(x), 2)]

            for i in range(numVariables):
                lista = nueva_lista[i]
                nuevatupler = []

                for elementer in lista:
                    setsList[i].add(int(elementer))
                    nuevatupler.append(int(elementer))

                nuevatupler = tuple(nuevatupler)
                tuples.append(nuevatupler)

            input.append(IntervalImplicant(tuples))

        for i in range(numVariables):
            setordenado = sorted(setsList[i])
            setsList[i] = setordenado

        self.stages = setsList

        return input
    
    @classmethod
    def readOptimizedIntervalInput(self, filename):
        file = open(filename)
        lines = file.read().splitlines()
        input = []
        
        numVariables = int(lines[0])
        lines.pop(0)

        setsList = []

        for i in range(numVariables):
            nuevoSetVariable = set()
            nuevoSetVariable.update([0, int(lines[0])])
            lines.pop(0)
            setsList.append(nuevoSetVariable)

        for element in lines:
            x = element.split()
            tuples = [] 
            nueva_lista = [x[i:i+2] for i in range(0, len(x), 2)]

            for i in range(numVariables):
                lista = nueva_lista[i]
                nuevatupler = []

                for elementer in lista:
                    setsList[i].add(int(elementer))
                    nuevatupler.append(int(elementer))

                nuevatupler = tuple(nuevatupler)
                tuples.append(nuevatupler)

            input.append(optimizedIntervalImplicant(tuples))

        for i in range(numVariables):
            setordenado = sorted(setsList[i])
            setsList[i] = setordenado

        self.stages = setsList

        return input


from mindt_Selino.dtMinimisation import DtMinimisation
import sys

def main():
    print(sys.argv[0])
    if len(sys.argv)<2:
        print("Please give a file path")
        return

    minimizer = DtMinimisation(sys.argv[1])
    print("minimized")
    
    if len(sys.argv) > 2:
        minimizer.saveOutputInFile(sys.argv[2])

if __name__ == "__main__":
    main()